start

Note that lookupserver has been replaced by tmserver as the best way to provide a translation memory service. This is kept for reference only. Tmserver should be used for all work.

# lookupserver

The lookupserver is a service that can be accessed via http and queried via XML-RPC. It can perform lookup of strings in certain storage formats.

## Usage

    lookupserver [--port=portnumber] [--address=hostname] [--language=languagename] storagefile

where storagefile is the file from which queries must be answered.

Options:

--port | set the port number on which to listen
--address | the hostname to bind to
--language | the target language for the lookup operation

## Testing

The server can be queried using any XML-RPC client. Example code is provided in the file lookupclient.py. Running

     python lookupclient.py

with no parameters will connect to a lookupserver on the localhost as long as default settings were used by the server. Words can then be typed in and the reply from the server will be displayed in the client in the native format of the file store used by the server.